'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

class ResponseFactory {
    static init() {
        const response = {
            statusCode: 500,
            headers: {
                'Access-Control-Allow-Origin': '*',
                'Access-Control-Allow-Credentials': true
            },
            body: JSON.stringify({
                message: 'Internal Server Error'
            })
        };
        return {
            setStatusCode(code) {
                response.statusCode = code;
                return this;
            },
            updateHeader(key, value) {
                if (!response.headers) {
                    response.headers = {
                        [key]: value
                    };
                }
                else {
                    response.headers[key] = value;
                }
                return this;
            },
            putHeaders(headers) {
                response.headers = headers;
                return this;
            },
            setBody(body) {
                if (!body)
                    return this.unsetBody();
                response.body = typeof body !== 'string' ? JSON.stringify(body) : body;
                return this;
            },
            unsetBody() {
                delete response.body;
                return this;
            },
            getResponse() {
                return response;
            }
        };
    }
}

const ResponseBuilder = ResponseFactory.init();
var index = {
    ResponseFactory,
    ResponseBuilder
};
module.exports = {
    ResponseFactory,
    ResponseBuilder
};

exports.ResponseBuilder = ResponseBuilder;
exports.ResponseFactory = ResponseFactory;
exports.default = index;
